@@ -91,10 +91,14 @@ main (int argc, char *argv[])
     fscanf(fid, "%s", scrollkeeper_data_dir);
     pclose(fid);
     
-    create_database_directory(scrollkeeper_dir, scrollkeeper_data_dir);
+    if (create_database_directory(scrollkeeper_dir, scrollkeeper_data_dir, outputprefs) != 0) {
+        sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "scrollkeeper-install", _("Could not create database.  Aborting install.\n"));
+        return 1;
+    }
     
     sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "scrollkeeper-install", _("Registering %s\n"), omf_name);
     if (! install(omf_name, scrollkeeper_dir, scrollkeeper_data_dir, outputprefs)) {
+    	sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "scrollkeeper-install", _("Unable to register %s\n"), omf_name);
     	exit(EXIT_FAILURE);
     }
      
